# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['PromptPartialsArgs', 'PromptPartials']

@pulumi.input_type
class PromptPartialsArgs:
    def __init__(__self__, *,
                 prompt: pulumi.Input[str],
                 form_content_end: Optional[pulumi.Input[str]] = None,
                 form_content_start: Optional[pulumi.Input[str]] = None,
                 form_footer_end: Optional[pulumi.Input[str]] = None,
                 form_footer_start: Optional[pulumi.Input[str]] = None,
                 secondary_actions_end: Optional[pulumi.Input[str]] = None,
                 secondary_actions_start: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a PromptPartials resource.
        :param pulumi.Input[str] prompt: The prompt that you are adding partials for. Options are: `login-id`, `login`, `login-password`, `signup`, `signup-id`, `signup-password`.
        :param pulumi.Input[str] form_content_end: Content that goes at the end of the form.
        :param pulumi.Input[str] form_content_start: Content that goes at the start of the form.
        :param pulumi.Input[str] form_footer_end: Footer content for the end of the footer.
        :param pulumi.Input[str] form_footer_start: Footer content for the start of the footer.
        :param pulumi.Input[str] secondary_actions_end: Actions that go at the end of secondary actions.
        :param pulumi.Input[str] secondary_actions_start: Actions that go at the start of secondary actions.
        """
        pulumi.set(__self__, "prompt", prompt)
        if form_content_end is not None:
            pulumi.set(__self__, "form_content_end", form_content_end)
        if form_content_start is not None:
            pulumi.set(__self__, "form_content_start", form_content_start)
        if form_footer_end is not None:
            pulumi.set(__self__, "form_footer_end", form_footer_end)
        if form_footer_start is not None:
            pulumi.set(__self__, "form_footer_start", form_footer_start)
        if secondary_actions_end is not None:
            pulumi.set(__self__, "secondary_actions_end", secondary_actions_end)
        if secondary_actions_start is not None:
            pulumi.set(__self__, "secondary_actions_start", secondary_actions_start)

    @property
    @pulumi.getter
    def prompt(self) -> pulumi.Input[str]:
        """
        The prompt that you are adding partials for. Options are: `login-id`, `login`, `login-password`, `signup`, `signup-id`, `signup-password`.
        """
        return pulumi.get(self, "prompt")

    @prompt.setter
    def prompt(self, value: pulumi.Input[str]):
        pulumi.set(self, "prompt", value)

    @property
    @pulumi.getter(name="formContentEnd")
    def form_content_end(self) -> Optional[pulumi.Input[str]]:
        """
        Content that goes at the end of the form.
        """
        return pulumi.get(self, "form_content_end")

    @form_content_end.setter
    def form_content_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "form_content_end", value)

    @property
    @pulumi.getter(name="formContentStart")
    def form_content_start(self) -> Optional[pulumi.Input[str]]:
        """
        Content that goes at the start of the form.
        """
        return pulumi.get(self, "form_content_start")

    @form_content_start.setter
    def form_content_start(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "form_content_start", value)

    @property
    @pulumi.getter(name="formFooterEnd")
    def form_footer_end(self) -> Optional[pulumi.Input[str]]:
        """
        Footer content for the end of the footer.
        """
        return pulumi.get(self, "form_footer_end")

    @form_footer_end.setter
    def form_footer_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "form_footer_end", value)

    @property
    @pulumi.getter(name="formFooterStart")
    def form_footer_start(self) -> Optional[pulumi.Input[str]]:
        """
        Footer content for the start of the footer.
        """
        return pulumi.get(self, "form_footer_start")

    @form_footer_start.setter
    def form_footer_start(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "form_footer_start", value)

    @property
    @pulumi.getter(name="secondaryActionsEnd")
    def secondary_actions_end(self) -> Optional[pulumi.Input[str]]:
        """
        Actions that go at the end of secondary actions.
        """
        return pulumi.get(self, "secondary_actions_end")

    @secondary_actions_end.setter
    def secondary_actions_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secondary_actions_end", value)

    @property
    @pulumi.getter(name="secondaryActionsStart")
    def secondary_actions_start(self) -> Optional[pulumi.Input[str]]:
        """
        Actions that go at the start of secondary actions.
        """
        return pulumi.get(self, "secondary_actions_start")

    @secondary_actions_start.setter
    def secondary_actions_start(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secondary_actions_start", value)


@pulumi.input_type
class _PromptPartialsState:
    def __init__(__self__, *,
                 form_content_end: Optional[pulumi.Input[str]] = None,
                 form_content_start: Optional[pulumi.Input[str]] = None,
                 form_footer_end: Optional[pulumi.Input[str]] = None,
                 form_footer_start: Optional[pulumi.Input[str]] = None,
                 prompt: Optional[pulumi.Input[str]] = None,
                 secondary_actions_end: Optional[pulumi.Input[str]] = None,
                 secondary_actions_start: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering PromptPartials resources.
        :param pulumi.Input[str] form_content_end: Content that goes at the end of the form.
        :param pulumi.Input[str] form_content_start: Content that goes at the start of the form.
        :param pulumi.Input[str] form_footer_end: Footer content for the end of the footer.
        :param pulumi.Input[str] form_footer_start: Footer content for the start of the footer.
        :param pulumi.Input[str] prompt: The prompt that you are adding partials for. Options are: `login-id`, `login`, `login-password`, `signup`, `signup-id`, `signup-password`.
        :param pulumi.Input[str] secondary_actions_end: Actions that go at the end of secondary actions.
        :param pulumi.Input[str] secondary_actions_start: Actions that go at the start of secondary actions.
        """
        if form_content_end is not None:
            pulumi.set(__self__, "form_content_end", form_content_end)
        if form_content_start is not None:
            pulumi.set(__self__, "form_content_start", form_content_start)
        if form_footer_end is not None:
            pulumi.set(__self__, "form_footer_end", form_footer_end)
        if form_footer_start is not None:
            pulumi.set(__self__, "form_footer_start", form_footer_start)
        if prompt is not None:
            pulumi.set(__self__, "prompt", prompt)
        if secondary_actions_end is not None:
            pulumi.set(__self__, "secondary_actions_end", secondary_actions_end)
        if secondary_actions_start is not None:
            pulumi.set(__self__, "secondary_actions_start", secondary_actions_start)

    @property
    @pulumi.getter(name="formContentEnd")
    def form_content_end(self) -> Optional[pulumi.Input[str]]:
        """
        Content that goes at the end of the form.
        """
        return pulumi.get(self, "form_content_end")

    @form_content_end.setter
    def form_content_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "form_content_end", value)

    @property
    @pulumi.getter(name="formContentStart")
    def form_content_start(self) -> Optional[pulumi.Input[str]]:
        """
        Content that goes at the start of the form.
        """
        return pulumi.get(self, "form_content_start")

    @form_content_start.setter
    def form_content_start(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "form_content_start", value)

    @property
    @pulumi.getter(name="formFooterEnd")
    def form_footer_end(self) -> Optional[pulumi.Input[str]]:
        """
        Footer content for the end of the footer.
        """
        return pulumi.get(self, "form_footer_end")

    @form_footer_end.setter
    def form_footer_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "form_footer_end", value)

    @property
    @pulumi.getter(name="formFooterStart")
    def form_footer_start(self) -> Optional[pulumi.Input[str]]:
        """
        Footer content for the start of the footer.
        """
        return pulumi.get(self, "form_footer_start")

    @form_footer_start.setter
    def form_footer_start(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "form_footer_start", value)

    @property
    @pulumi.getter
    def prompt(self) -> Optional[pulumi.Input[str]]:
        """
        The prompt that you are adding partials for. Options are: `login-id`, `login`, `login-password`, `signup`, `signup-id`, `signup-password`.
        """
        return pulumi.get(self, "prompt")

    @prompt.setter
    def prompt(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "prompt", value)

    @property
    @pulumi.getter(name="secondaryActionsEnd")
    def secondary_actions_end(self) -> Optional[pulumi.Input[str]]:
        """
        Actions that go at the end of secondary actions.
        """
        return pulumi.get(self, "secondary_actions_end")

    @secondary_actions_end.setter
    def secondary_actions_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secondary_actions_end", value)

    @property
    @pulumi.getter(name="secondaryActionsStart")
    def secondary_actions_start(self) -> Optional[pulumi.Input[str]]:
        """
        Actions that go at the start of secondary actions.
        """
        return pulumi.get(self, "secondary_actions_start")

    @secondary_actions_start.setter
    def secondary_actions_start(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secondary_actions_start", value)


class PromptPartials(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 form_content_end: Optional[pulumi.Input[str]] = None,
                 form_content_start: Optional[pulumi.Input[str]] = None,
                 form_footer_end: Optional[pulumi.Input[str]] = None,
                 form_footer_start: Optional[pulumi.Input[str]] = None,
                 prompt: Optional[pulumi.Input[str]] = None,
                 secondary_actions_end: Optional[pulumi.Input[str]] = None,
                 secondary_actions_start: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        With this resource, you can manage a customized sign up and login experience by adding custom content, form elements and css/javascript. You can read more about this [here](https://auth0.com/docs/customize/universal-login-pages/customize-signup-and-login-prompts).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        my_login_prompt_partials = auth0.PromptPartials("my_login_prompt_partials",
            prompt="login",
            form_content_start="<div>Updated Form Content Start</div>",
            form_content_end="<div>Updated Form Content End</div>",
            form_footer_start="<div>Updated Footer Start</div>",
            form_footer_end="<div>Updated Footer End</div>",
            secondary_actions_start="<div>Updated Secondary Actions Start</div>",
            secondary_actions_end="<div>Updated Secondary Actions End</div>")
        ```

        ## Import

        This resource can be imported using the prompt name.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/promptPartials:PromptPartials my_login_prompt_partials "login"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] form_content_end: Content that goes at the end of the form.
        :param pulumi.Input[str] form_content_start: Content that goes at the start of the form.
        :param pulumi.Input[str] form_footer_end: Footer content for the end of the footer.
        :param pulumi.Input[str] form_footer_start: Footer content for the start of the footer.
        :param pulumi.Input[str] prompt: The prompt that you are adding partials for. Options are: `login-id`, `login`, `login-password`, `signup`, `signup-id`, `signup-password`.
        :param pulumi.Input[str] secondary_actions_end: Actions that go at the end of secondary actions.
        :param pulumi.Input[str] secondary_actions_start: Actions that go at the start of secondary actions.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PromptPartialsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        With this resource, you can manage a customized sign up and login experience by adding custom content, form elements and css/javascript. You can read more about this [here](https://auth0.com/docs/customize/universal-login-pages/customize-signup-and-login-prompts).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        my_login_prompt_partials = auth0.PromptPartials("my_login_prompt_partials",
            prompt="login",
            form_content_start="<div>Updated Form Content Start</div>",
            form_content_end="<div>Updated Form Content End</div>",
            form_footer_start="<div>Updated Footer Start</div>",
            form_footer_end="<div>Updated Footer End</div>",
            secondary_actions_start="<div>Updated Secondary Actions Start</div>",
            secondary_actions_end="<div>Updated Secondary Actions End</div>")
        ```

        ## Import

        This resource can be imported using the prompt name.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/promptPartials:PromptPartials my_login_prompt_partials "login"
        ```

        :param str resource_name: The name of the resource.
        :param PromptPartialsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PromptPartialsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 form_content_end: Optional[pulumi.Input[str]] = None,
                 form_content_start: Optional[pulumi.Input[str]] = None,
                 form_footer_end: Optional[pulumi.Input[str]] = None,
                 form_footer_start: Optional[pulumi.Input[str]] = None,
                 prompt: Optional[pulumi.Input[str]] = None,
                 secondary_actions_end: Optional[pulumi.Input[str]] = None,
                 secondary_actions_start: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PromptPartialsArgs.__new__(PromptPartialsArgs)

            __props__.__dict__["form_content_end"] = form_content_end
            __props__.__dict__["form_content_start"] = form_content_start
            __props__.__dict__["form_footer_end"] = form_footer_end
            __props__.__dict__["form_footer_start"] = form_footer_start
            if prompt is None and not opts.urn:
                raise TypeError("Missing required property 'prompt'")
            __props__.__dict__["prompt"] = prompt
            __props__.__dict__["secondary_actions_end"] = secondary_actions_end
            __props__.__dict__["secondary_actions_start"] = secondary_actions_start
        super(PromptPartials, __self__).__init__(
            'auth0:index/promptPartials:PromptPartials',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            form_content_end: Optional[pulumi.Input[str]] = None,
            form_content_start: Optional[pulumi.Input[str]] = None,
            form_footer_end: Optional[pulumi.Input[str]] = None,
            form_footer_start: Optional[pulumi.Input[str]] = None,
            prompt: Optional[pulumi.Input[str]] = None,
            secondary_actions_end: Optional[pulumi.Input[str]] = None,
            secondary_actions_start: Optional[pulumi.Input[str]] = None) -> 'PromptPartials':
        """
        Get an existing PromptPartials resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] form_content_end: Content that goes at the end of the form.
        :param pulumi.Input[str] form_content_start: Content that goes at the start of the form.
        :param pulumi.Input[str] form_footer_end: Footer content for the end of the footer.
        :param pulumi.Input[str] form_footer_start: Footer content for the start of the footer.
        :param pulumi.Input[str] prompt: The prompt that you are adding partials for. Options are: `login-id`, `login`, `login-password`, `signup`, `signup-id`, `signup-password`.
        :param pulumi.Input[str] secondary_actions_end: Actions that go at the end of secondary actions.
        :param pulumi.Input[str] secondary_actions_start: Actions that go at the start of secondary actions.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PromptPartialsState.__new__(_PromptPartialsState)

        __props__.__dict__["form_content_end"] = form_content_end
        __props__.__dict__["form_content_start"] = form_content_start
        __props__.__dict__["form_footer_end"] = form_footer_end
        __props__.__dict__["form_footer_start"] = form_footer_start
        __props__.__dict__["prompt"] = prompt
        __props__.__dict__["secondary_actions_end"] = secondary_actions_end
        __props__.__dict__["secondary_actions_start"] = secondary_actions_start
        return PromptPartials(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="formContentEnd")
    def form_content_end(self) -> pulumi.Output[Optional[str]]:
        """
        Content that goes at the end of the form.
        """
        return pulumi.get(self, "form_content_end")

    @property
    @pulumi.getter(name="formContentStart")
    def form_content_start(self) -> pulumi.Output[Optional[str]]:
        """
        Content that goes at the start of the form.
        """
        return pulumi.get(self, "form_content_start")

    @property
    @pulumi.getter(name="formFooterEnd")
    def form_footer_end(self) -> pulumi.Output[Optional[str]]:
        """
        Footer content for the end of the footer.
        """
        return pulumi.get(self, "form_footer_end")

    @property
    @pulumi.getter(name="formFooterStart")
    def form_footer_start(self) -> pulumi.Output[Optional[str]]:
        """
        Footer content for the start of the footer.
        """
        return pulumi.get(self, "form_footer_start")

    @property
    @pulumi.getter
    def prompt(self) -> pulumi.Output[str]:
        """
        The prompt that you are adding partials for. Options are: `login-id`, `login`, `login-password`, `signup`, `signup-id`, `signup-password`.
        """
        return pulumi.get(self, "prompt")

    @property
    @pulumi.getter(name="secondaryActionsEnd")
    def secondary_actions_end(self) -> pulumi.Output[Optional[str]]:
        """
        Actions that go at the end of secondary actions.
        """
        return pulumi.get(self, "secondary_actions_end")

    @property
    @pulumi.getter(name="secondaryActionsStart")
    def secondary_actions_start(self) -> pulumi.Output[Optional[str]]:
        """
        Actions that go at the start of secondary actions.
        """
        return pulumi.get(self, "secondary_actions_start")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .action import *
from .attack_protection import *
from .branding import *
from .branding_theme import *
from .client import *
from .client_credentials import *
from .client_grant import *
from .connection import *
from .connection_client import *
from .connection_clients import *
from .custom_domain import *
from .custom_domain_verification import *
from .email_provider import *
from .email_template import *
from .get_attack_protection import *
from .get_branding import *
from .get_branding_theme import *
from .get_client import *
from .get_connection import *
from .get_custom_domain import *
from .get_organization import *
from .get_pages import *
from .get_resource_server import *
from .get_role import *
from .get_signing_keys import *
from .get_tenant import *
from .get_user import *
from .guardian import *
from .hook import *
from .log_stream import *
from .organization import *
from .organization_connection import *
from .organization_connections import *
from .organization_member import *
from .organization_member_role import *
from .organization_member_roles import *
from .organization_members import *
from .pages import *
from .prompt import *
from .prompt_custom_text import *
from .prompt_partials import *
from .provider import *
from .resource_server import *
from .resource_server_scope import *
from .resource_server_scopes import *
from .role import *
from .role_permission import *
from .role_permissions import *
from .rule import *
from .rule_config import *
from .tenant import *
from .trigger_action import *
from .trigger_actions import *
from .user import *
from .user_permission import *
from .user_permissions import *
from .user_role import *
from .user_roles import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_auth0.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_auth0.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "auth0",
  "mod": "index/action",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/action:Action": "Action"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/attackProtection",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/attackProtection:AttackProtection": "AttackProtection"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/branding",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/branding:Branding": "Branding"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/brandingTheme",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/brandingTheme:BrandingTheme": "BrandingTheme"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/client",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/client:Client": "Client"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/clientCredentials",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/clientCredentials:ClientCredentials": "ClientCredentials"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/clientGrant",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/clientGrant:ClientGrant": "ClientGrant"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/connection",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/connectionClient",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/connectionClient:ConnectionClient": "ConnectionClient"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/connectionClients",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/connectionClients:ConnectionClients": "ConnectionClients"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/customDomain",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/customDomain:CustomDomain": "CustomDomain"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/customDomainVerification",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/customDomainVerification:CustomDomainVerification": "CustomDomainVerification"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/emailProvider",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/emailProvider:EmailProvider": "EmailProvider"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/emailTemplate",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/emailTemplate:EmailTemplate": "EmailTemplate"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/guardian",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/guardian:Guardian": "Guardian"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/hook",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/hook:Hook": "Hook"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/logStream",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/logStream:LogStream": "LogStream"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/organization",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/organization:Organization": "Organization"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/organizationConnection",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/organizationConnection:OrganizationConnection": "OrganizationConnection"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/organizationConnections",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/organizationConnections:OrganizationConnections": "OrganizationConnections"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/organizationMember",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/organizationMember:OrganizationMember": "OrganizationMember"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/organizationMemberRole",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/organizationMemberRole:OrganizationMemberRole": "OrganizationMemberRole"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/organizationMemberRoles",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/organizationMemberRoles:OrganizationMemberRoles": "OrganizationMemberRoles"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/organizationMembers",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/organizationMembers:OrganizationMembers": "OrganizationMembers"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/pages",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/pages:Pages": "Pages"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/prompt",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/prompt:Prompt": "Prompt"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/promptCustomText",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/promptCustomText:PromptCustomText": "PromptCustomText"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/promptPartials",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/promptPartials:PromptPartials": "PromptPartials"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/resourceServer",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/resourceServer:ResourceServer": "ResourceServer"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/resourceServerScope",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/resourceServerScope:ResourceServerScope": "ResourceServerScope"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/resourceServerScopes",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/resourceServerScopes:ResourceServerScopes": "ResourceServerScopes"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/role",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/role:Role": "Role"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/rolePermission",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/rolePermission:RolePermission": "RolePermission"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/rolePermissions",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/rolePermissions:RolePermissions": "RolePermissions"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/rule",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/ruleConfig",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/ruleConfig:RuleConfig": "RuleConfig"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/tenant",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/tenant:Tenant": "Tenant"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/triggerAction",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/triggerAction:TriggerAction": "TriggerAction"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/triggerActions",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/triggerActions:TriggerActions": "TriggerActions"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/user",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/user:User": "User"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/userPermission",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/userPermission:UserPermission": "UserPermission"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/userPermissions",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/userPermissions:UserPermissions": "UserPermissions"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/userRole",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/userRole:UserRole": "UserRole"
  }
 },
 {
  "pkg": "auth0",
  "mod": "index/userRoles",
  "fqn": "pulumi_auth0",
  "classes": {
   "auth0:index/userRoles:UserRoles": "UserRoles"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "auth0",
  "token": "pulumi:providers:auth0",
  "fqn": "pulumi_auth0",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['RuleConfigArgs', 'RuleConfig']

@pulumi.input_type
class RuleConfigArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        """
        The set of arguments for constructing a RuleConfig resource.
        :param pulumi.Input[str] key: Key for a rules configuration variable.
        :param pulumi.Input[str] value: Value for a rules configuration variable.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        """
        Key for a rules configuration variable.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        """
        Value for a rules configuration variable.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class _RuleConfigState:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering RuleConfig resources.
        :param pulumi.Input[str] key: Key for a rules configuration variable.
        :param pulumi.Input[str] value: Value for a rules configuration variable.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        Key for a rules configuration variable.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        Value for a rules configuration variable.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


class RuleConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        With Auth0, you can create custom Javascript snippets that run in a secure, isolated sandbox as part of your authentication pipeline, which are otherwise known as rules. This resource allows you to create and manage variables that are available to all rules via Auth0's global configuration object. Used in conjunction with configured rules.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        my_rule = auth0.Rule("my_rule",
            name="empty-rule",
            script=\"\"\"    function (user, context, callback) {
              callback(null, user, context);
            }
        \"\"\",
            enabled=True)
        my_rule_config = auth0.RuleConfig("my_rule_config",
            key="foo",
            value="bar")
        ```

        ## Import

        Existing rule configs can be imported using their key name.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/ruleConfig:RuleConfig my_rule_config "foo"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] key: Key for a rules configuration variable.
        :param pulumi.Input[str] value: Value for a rules configuration variable.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RuleConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        With Auth0, you can create custom Javascript snippets that run in a secure, isolated sandbox as part of your authentication pipeline, which are otherwise known as rules. This resource allows you to create and manage variables that are available to all rules via Auth0's global configuration object. Used in conjunction with configured rules.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        my_rule = auth0.Rule("my_rule",
            name="empty-rule",
            script=\"\"\"    function (user, context, callback) {
              callback(null, user, context);
            }
        \"\"\",
            enabled=True)
        my_rule_config = auth0.RuleConfig("my_rule_config",
            key="foo",
            value="bar")
        ```

        ## Import

        Existing rule configs can be imported using their key name.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/ruleConfig:RuleConfig my_rule_config "foo"
        ```

        :param str resource_name: The name of the resource.
        :param RuleConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RuleConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RuleConfigArgs.__new__(RuleConfigArgs)

            if key is None and not opts.urn:
                raise TypeError("Missing required property 'key'")
            __props__.__dict__["key"] = key
            if value is None and not opts.urn:
                raise TypeError("Missing required property 'value'")
            __props__.__dict__["value"] = None if value is None else pulumi.Output.secret(value)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["value"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(RuleConfig, __self__).__init__(
            'auth0:index/ruleConfig:RuleConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            key: Optional[pulumi.Input[str]] = None,
            value: Optional[pulumi.Input[str]] = None) -> 'RuleConfig':
        """
        Get an existing RuleConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] key: Key for a rules configuration variable.
        :param pulumi.Input[str] value: Value for a rules configuration variable.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RuleConfigState.__new__(_RuleConfigState)

        __props__.__dict__["key"] = key
        __props__.__dict__["value"] = value
        return RuleConfig(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Output[str]:
        """
        Key for a rules configuration variable.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> pulumi.Output[str]:
        """
        Value for a rules configuration variable.
        """
        return pulumi.get(self, "value")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['OrganizationArgs', 'Organization']

@pulumi.input_type
class OrganizationArgs:
    def __init__(__self__, *,
                 branding: Optional[pulumi.Input['OrganizationBrandingArgs']] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Organization resource.
        :param pulumi.Input['OrganizationBrandingArgs'] branding: Defines how to style the login pages.
        :param pulumi.Input[str] display_name: Friendly name of this organization.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: Metadata associated with the organization. Maximum of 10 metadata properties allowed.
        :param pulumi.Input[str] name: The name of this organization.
        """
        if branding is not None:
            pulumi.set(__self__, "branding", branding)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def branding(self) -> Optional[pulumi.Input['OrganizationBrandingArgs']]:
        """
        Defines how to style the login pages.
        """
        return pulumi.get(self, "branding")

    @branding.setter
    def branding(self, value: Optional[pulumi.Input['OrganizationBrandingArgs']]):
        pulumi.set(self, "branding", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        Friendly name of this organization.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Metadata associated with the organization. Maximum of 10 metadata properties allowed.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of this organization.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _OrganizationState:
    def __init__(__self__, *,
                 branding: Optional[pulumi.Input['OrganizationBrandingArgs']] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Organization resources.
        :param pulumi.Input['OrganizationBrandingArgs'] branding: Defines how to style the login pages.
        :param pulumi.Input[str] display_name: Friendly name of this organization.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: Metadata associated with the organization. Maximum of 10 metadata properties allowed.
        :param pulumi.Input[str] name: The name of this organization.
        """
        if branding is not None:
            pulumi.set(__self__, "branding", branding)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def branding(self) -> Optional[pulumi.Input['OrganizationBrandingArgs']]:
        """
        Defines how to style the login pages.
        """
        return pulumi.get(self, "branding")

    @branding.setter
    def branding(self, value: Optional[pulumi.Input['OrganizationBrandingArgs']]):
        pulumi.set(self, "branding", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        Friendly name of this organization.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Metadata associated with the organization. Maximum of 10 metadata properties allowed.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of this organization.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class Organization(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 branding: Optional[pulumi.Input[pulumi.InputType['OrganizationBrandingArgs']]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The Organizations feature represents a broad update to the Auth0 platform that allows our business-to-business (B2B) customers to better manage their partners and customers, and to customize the ways that end-users access their applications. Auth0 customers can use Organizations to:

          - Represent their business customers and partners in Auth0 and manage their
            membership.
          - Configure branded, federated login flows for each business.
          - Build administration capabilities into their products, using Organizations
            APIs, so that those businesses can manage their own organizations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        my_organization = auth0.Organization("my_organization",
            name="auth0-inc",
            display_name="Auth0 Inc.",
            branding=auth0.OrganizationBrandingArgs(
                logo_url="https://example.com/assets/icons/icon.png",
                colors={
                    "primary": "#f2f2f2",
                    "page_background": "#e1e1e1",
                },
            ))
        ```

        ## Import

        This resource can be imported by specifying the organization ID.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/organization:Organization my_organization "org_XXXXXXXXXXXXXX"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['OrganizationBrandingArgs']] branding: Defines how to style the login pages.
        :param pulumi.Input[str] display_name: Friendly name of this organization.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: Metadata associated with the organization. Maximum of 10 metadata properties allowed.
        :param pulumi.Input[str] name: The name of this organization.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[OrganizationArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The Organizations feature represents a broad update to the Auth0 platform that allows our business-to-business (B2B) customers to better manage their partners and customers, and to customize the ways that end-users access their applications. Auth0 customers can use Organizations to:

          - Represent their business customers and partners in Auth0 and manage their
            membership.
          - Configure branded, federated login flows for each business.
          - Build administration capabilities into their products, using Organizations
            APIs, so that those businesses can manage their own organizations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        my_organization = auth0.Organization("my_organization",
            name="auth0-inc",
            display_name="Auth0 Inc.",
            branding=auth0.OrganizationBrandingArgs(
                logo_url="https://example.com/assets/icons/icon.png",
                colors={
                    "primary": "#f2f2f2",
                    "page_background": "#e1e1e1",
                },
            ))
        ```

        ## Import

        This resource can be imported by specifying the organization ID.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/organization:Organization my_organization "org_XXXXXXXXXXXXXX"
        ```

        :param str resource_name: The name of the resource.
        :param OrganizationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OrganizationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 branding: Optional[pulumi.Input[pulumi.InputType['OrganizationBrandingArgs']]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OrganizationArgs.__new__(OrganizationArgs)

            __props__.__dict__["branding"] = branding
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["metadata"] = metadata
            __props__.__dict__["name"] = name
        super(Organization, __self__).__init__(
            'auth0:index/organization:Organization',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            branding: Optional[pulumi.Input[pulumi.InputType['OrganizationBrandingArgs']]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'Organization':
        """
        Get an existing Organization resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['OrganizationBrandingArgs']] branding: Defines how to style the login pages.
        :param pulumi.Input[str] display_name: Friendly name of this organization.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: Metadata associated with the organization. Maximum of 10 metadata properties allowed.
        :param pulumi.Input[str] name: The name of this organization.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OrganizationState.__new__(_OrganizationState)

        __props__.__dict__["branding"] = branding
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["metadata"] = metadata
        __props__.__dict__["name"] = name
        return Organization(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def branding(self) -> pulumi.Output['outputs.OrganizationBranding']:
        """
        Defines how to style the login pages.
        """
        return pulumi.get(self, "branding")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[str]]:
        """
        Friendly name of this organization.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def metadata(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Metadata associated with the organization. Maximum of 10 metadata properties allowed.
        """
        return pulumi.get(self, "metadata")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of this organization.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetSigningKeysResult',
    'AwaitableGetSigningKeysResult',
    'get_signing_keys',
    'get_signing_keys_output',
]

@pulumi.output_type
class GetSigningKeysResult:
    """
    A collection of values returned by getSigningKeys.
    """
    def __init__(__self__, id=None, signing_keys=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if signing_keys and not isinstance(signing_keys, list):
            raise TypeError("Expected argument 'signing_keys' to be a list")
        pulumi.set(__self__, "signing_keys", signing_keys)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="signingKeys")
    def signing_keys(self) -> Sequence['outputs.GetSigningKeysSigningKeyResult']:
        """
        All application signing keys.
        """
        return pulumi.get(self, "signing_keys")


class AwaitableGetSigningKeysResult(GetSigningKeysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSigningKeysResult(
            id=self.id,
            signing_keys=self.signing_keys)


def get_signing_keys(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSigningKeysResult:
    """
    Data source to retrieve signing keys used by the applications in your tenant. [Learn more](https://auth0.com/docs/get-started/tenant-settings/signing-keys).
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('auth0:index/getSigningKeys:getSigningKeys', __args__, opts=opts, typ=GetSigningKeysResult).value

    return AwaitableGetSigningKeysResult(
        id=pulumi.get(__ret__, 'id'),
        signing_keys=pulumi.get(__ret__, 'signing_keys'))


@_utilities.lift_output_func(get_signing_keys)
def get_signing_keys_output(opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSigningKeysResult]:
    """
    Data source to retrieve signing keys used by the applications in your tenant. [Learn more](https://auth0.com/docs/get-started/tenant-settings/signing-keys).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LogStreamArgs', 'LogStream']

@pulumi.input_type
class LogStreamArgs:
    def __init__(__self__, *,
                 sink: pulumi.Input['LogStreamSinkArgs'],
                 type: pulumi.Input[str],
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a LogStream resource.
        :param pulumi.Input['LogStreamSinkArgs'] sink: The sink configuration for the log stream.
        :param pulumi.Input[str] type: Type of the log stream, which indicates the sink provider. Options include: `eventbridge`, `eventgrid`, `http`, `datadog`, `splunk`, `sumo`, `mixpanel`, `segment`.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] filters: Only logs events matching these filters will be delivered by the stream. If omitted or empty, all events will be delivered. Filters available: `auth.ancillary.fail`, `auth.ancillary.success`, `auth.login.fail`, `auth.login.notification`, `auth.login.success`, `auth.logout.fail`, `auth.logout.success`, `auth.signup.fail`, `auth.signup.success`, `auth.silent_auth.fail`, `auth.silent_auth.success`, `auth.token_exchange.fail`, `auth.token_exchange.success`, `management.fail`, `management.success`, `system.notification`, `user.fail`, `user.notification`, `user.success`, `other`.
        :param pulumi.Input[str] name: Name of the log stream.
        :param pulumi.Input[str] status: The current status of the log stream. Options are "active", "paused", "suspended".
        """
        pulumi.set(__self__, "sink", sink)
        pulumi.set(__self__, "type", type)
        if filters is not None:
            pulumi.set(__self__, "filters", filters)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def sink(self) -> pulumi.Input['LogStreamSinkArgs']:
        """
        The sink configuration for the log stream.
        """
        return pulumi.get(self, "sink")

    @sink.setter
    def sink(self, value: pulumi.Input['LogStreamSinkArgs']):
        pulumi.set(self, "sink", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Type of the log stream, which indicates the sink provider. Options include: `eventbridge`, `eventgrid`, `http`, `datadog`, `splunk`, `sumo`, `mixpanel`, `segment`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]:
        """
        Only logs events matching these filters will be delivered by the stream. If omitted or empty, all events will be delivered. Filters available: `auth.ancillary.fail`, `auth.ancillary.success`, `auth.login.fail`, `auth.login.notification`, `auth.login.success`, `auth.logout.fail`, `auth.logout.success`, `auth.signup.fail`, `auth.signup.success`, `auth.silent_auth.fail`, `auth.silent_auth.success`, `auth.token_exchange.fail`, `auth.token_exchange.success`, `management.fail`, `management.success`, `system.notification`, `user.fail`, `user.notification`, `user.success`, `other`.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]):
        pulumi.set(self, "filters", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the log stream.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The current status of the log stream. Options are "active", "paused", "suspended".
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _LogStreamState:
    def __init__(__self__, *,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 sink: Optional[pulumi.Input['LogStreamSinkArgs']] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering LogStream resources.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] filters: Only logs events matching these filters will be delivered by the stream. If omitted or empty, all events will be delivered. Filters available: `auth.ancillary.fail`, `auth.ancillary.success`, `auth.login.fail`, `auth.login.notification`, `auth.login.success`, `auth.logout.fail`, `auth.logout.success`, `auth.signup.fail`, `auth.signup.success`, `auth.silent_auth.fail`, `auth.silent_auth.success`, `auth.token_exchange.fail`, `auth.token_exchange.success`, `management.fail`, `management.success`, `system.notification`, `user.fail`, `user.notification`, `user.success`, `other`.
        :param pulumi.Input[str] name: Name of the log stream.
        :param pulumi.Input['LogStreamSinkArgs'] sink: The sink configuration for the log stream.
        :param pulumi.Input[str] status: The current status of the log stream. Options are "active", "paused", "suspended".
        :param pulumi.Input[str] type: Type of the log stream, which indicates the sink provider. Options include: `eventbridge`, `eventgrid`, `http`, `datadog`, `splunk`, `sumo`, `mixpanel`, `segment`.
        """
        if filters is not None:
            pulumi.set(__self__, "filters", filters)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if sink is not None:
            pulumi.set(__self__, "sink", sink)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]:
        """
        Only logs events matching these filters will be delivered by the stream. If omitted or empty, all events will be delivered. Filters available: `auth.ancillary.fail`, `auth.ancillary.success`, `auth.login.fail`, `auth.login.notification`, `auth.login.success`, `auth.logout.fail`, `auth.logout.success`, `auth.signup.fail`, `auth.signup.success`, `auth.silent_auth.fail`, `auth.silent_auth.success`, `auth.token_exchange.fail`, `auth.token_exchange.success`, `management.fail`, `management.success`, `system.notification`, `user.fail`, `user.notification`, `user.success`, `other`.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]]):
        pulumi.set(self, "filters", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the log stream.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def sink(self) -> Optional[pulumi.Input['LogStreamSinkArgs']]:
        """
        The sink configuration for the log stream.
        """
        return pulumi.get(self, "sink")

    @sink.setter
    def sink(self, value: Optional[pulumi.Input['LogStreamSinkArgs']]):
        pulumi.set(self, "sink", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The current status of the log stream. Options are "active", "paused", "suspended".
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of the log stream, which indicates the sink provider. Options include: `eventbridge`, `eventgrid`, `http`, `datadog`, `splunk`, `sumo`, `mixpanel`, `segment`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


class LogStream(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 sink: Optional[pulumi.Input[pulumi.InputType['LogStreamSinkArgs']]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        With this resource, you can manage your Auth0 log streams.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an http log stream.
        my_webhook = auth0.LogStream("my_webhook",
            name="HTTP log stream",
            type="http",
            filters=[
                {
                    "type": "category",
                    "name": "auth.login.fail",
                },
                {
                    "type": "category",
                    "name": "auth.signup.fail",
                },
            ],
            sink=auth0.LogStreamSinkArgs(
                http_endpoint="https://example.com/logs",
                http_content_type="application/json",
                http_content_format="JSONOBJECT",
                http_authorization="AKIAXXXXXXXXXXXXXXXX",
                http_custom_headers=[{
                    "header": "foo",
                    "value": "bar",
                }],
            ))
        # This is an example of an Amazon EventBridge log stream.
        example_aws = auth0.LogStream("example_aws",
            name="AWS Eventbridge",
            type="eventbridge",
            status="active",
            sink=auth0.LogStreamSinkArgs(
                aws_account_id="my_account_id",
                aws_region="us-east-2",
            ))
        ```

        ## Import

        This resource can be imported by specifying the log stream ID.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/logStream:LogStream example "lst_XXXXXXXXXXXXXXXX"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] filters: Only logs events matching these filters will be delivered by the stream. If omitted or empty, all events will be delivered. Filters available: `auth.ancillary.fail`, `auth.ancillary.success`, `auth.login.fail`, `auth.login.notification`, `auth.login.success`, `auth.logout.fail`, `auth.logout.success`, `auth.signup.fail`, `auth.signup.success`, `auth.silent_auth.fail`, `auth.silent_auth.success`, `auth.token_exchange.fail`, `auth.token_exchange.success`, `management.fail`, `management.success`, `system.notification`, `user.fail`, `user.notification`, `user.success`, `other`.
        :param pulumi.Input[str] name: Name of the log stream.
        :param pulumi.Input[pulumi.InputType['LogStreamSinkArgs']] sink: The sink configuration for the log stream.
        :param pulumi.Input[str] status: The current status of the log stream. Options are "active", "paused", "suspended".
        :param pulumi.Input[str] type: Type of the log stream, which indicates the sink provider. Options include: `eventbridge`, `eventgrid`, `http`, `datadog`, `splunk`, `sumo`, `mixpanel`, `segment`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LogStreamArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        With this resource, you can manage your Auth0 log streams.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an http log stream.
        my_webhook = auth0.LogStream("my_webhook",
            name="HTTP log stream",
            type="http",
            filters=[
                {
                    "type": "category",
                    "name": "auth.login.fail",
                },
                {
                    "type": "category",
                    "name": "auth.signup.fail",
                },
            ],
            sink=auth0.LogStreamSinkArgs(
                http_endpoint="https://example.com/logs",
                http_content_type="application/json",
                http_content_format="JSONOBJECT",
                http_authorization="AKIAXXXXXXXXXXXXXXXX",
                http_custom_headers=[{
                    "header": "foo",
                    "value": "bar",
                }],
            ))
        # This is an example of an Amazon EventBridge log stream.
        example_aws = auth0.LogStream("example_aws",
            name="AWS Eventbridge",
            type="eventbridge",
            status="active",
            sink=auth0.LogStreamSinkArgs(
                aws_account_id="my_account_id",
                aws_region="us-east-2",
            ))
        ```

        ## Import

        This resource can be imported by specifying the log stream ID.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/logStream:LogStream example "lst_XXXXXXXXXXXXXXXX"
        ```

        :param str resource_name: The name of the resource.
        :param LogStreamArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LogStreamArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 sink: Optional[pulumi.Input[pulumi.InputType['LogStreamSinkArgs']]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LogStreamArgs.__new__(LogStreamArgs)

            __props__.__dict__["filters"] = filters
            __props__.__dict__["name"] = name
            if sink is None and not opts.urn:
                raise TypeError("Missing required property 'sink'")
            __props__.__dict__["sink"] = sink
            __props__.__dict__["status"] = status
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(LogStream, __self__).__init__(
            'auth0:index/logStream:LogStream',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            filters: Optional[pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            sink: Optional[pulumi.Input[pulumi.InputType['LogStreamSinkArgs']]] = None,
            status: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'LogStream':
        """
        Get an existing LogStream resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Mapping[str, pulumi.Input[str]]]]] filters: Only logs events matching these filters will be delivered by the stream. If omitted or empty, all events will be delivered. Filters available: `auth.ancillary.fail`, `auth.ancillary.success`, `auth.login.fail`, `auth.login.notification`, `auth.login.success`, `auth.logout.fail`, `auth.logout.success`, `auth.signup.fail`, `auth.signup.success`, `auth.silent_auth.fail`, `auth.silent_auth.success`, `auth.token_exchange.fail`, `auth.token_exchange.success`, `management.fail`, `management.success`, `system.notification`, `user.fail`, `user.notification`, `user.success`, `other`.
        :param pulumi.Input[str] name: Name of the log stream.
        :param pulumi.Input[pulumi.InputType['LogStreamSinkArgs']] sink: The sink configuration for the log stream.
        :param pulumi.Input[str] status: The current status of the log stream. Options are "active", "paused", "suspended".
        :param pulumi.Input[str] type: Type of the log stream, which indicates the sink provider. Options include: `eventbridge`, `eventgrid`, `http`, `datadog`, `splunk`, `sumo`, `mixpanel`, `segment`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LogStreamState.__new__(_LogStreamState)

        __props__.__dict__["filters"] = filters
        __props__.__dict__["name"] = name
        __props__.__dict__["sink"] = sink
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return LogStream(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def filters(self) -> pulumi.Output[Optional[Sequence[Mapping[str, str]]]]:
        """
        Only logs events matching these filters will be delivered by the stream. If omitted or empty, all events will be delivered. Filters available: `auth.ancillary.fail`, `auth.ancillary.success`, `auth.login.fail`, `auth.login.notification`, `auth.login.success`, `auth.logout.fail`, `auth.logout.success`, `auth.signup.fail`, `auth.signup.success`, `auth.silent_auth.fail`, `auth.silent_auth.success`, `auth.token_exchange.fail`, `auth.token_exchange.success`, `management.fail`, `management.success`, `system.notification`, `user.fail`, `user.notification`, `user.success`, `other`.
        """
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the log stream.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def sink(self) -> pulumi.Output['outputs.LogStreamSink']:
        """
        The sink configuration for the log stream.
        """
        return pulumi.get(self, "sink")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The current status of the log stream. Options are "active", "paused", "suspended".
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        Type of the log stream, which indicates the sink provider. Options include: `eventbridge`, `eventgrid`, `http`, `datadog`, `splunk`, `sumo`, `mixpanel`, `segment`.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetOrganizationResult',
    'AwaitableGetOrganizationResult',
    'get_organization',
    'get_organization_output',
]

@pulumi.output_type
class GetOrganizationResult:
    """
    A collection of values returned by getOrganization.
    """
    def __init__(__self__, brandings=None, connections=None, display_name=None, id=None, members=None, metadata=None, name=None, organization_id=None):
        if brandings and not isinstance(brandings, list):
            raise TypeError("Expected argument 'brandings' to be a list")
        pulumi.set(__self__, "brandings", brandings)
        if connections and not isinstance(connections, list):
            raise TypeError("Expected argument 'connections' to be a list")
        pulumi.set(__self__, "connections", connections)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        pulumi.set(__self__, "members", members)
        if metadata and not isinstance(metadata, dict):
            raise TypeError("Expected argument 'metadata' to be a dict")
        pulumi.set(__self__, "metadata", metadata)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)

    @property
    @pulumi.getter
    def brandings(self) -> Sequence['outputs.GetOrganizationBrandingResult']:
        """
        Defines how to style the login pages.
        """
        return pulumi.get(self, "brandings")

    @property
    @pulumi.getter
    def connections(self) -> Sequence['outputs.GetOrganizationConnectionResult']:
        return pulumi.get(self, "connections")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Friendly name of this organization.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def members(self) -> Sequence[str]:
        """
        User ID(s) that are members of the organization.
        """
        return pulumi.get(self, "members")

    @property
    @pulumi.getter
    def metadata(self) -> Mapping[str, str]:
        """
        Metadata associated with the organization. Maximum of 10 metadata properties allowed.
        """
        return pulumi.get(self, "metadata")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name of the organization. If not provided, `organization_id` must be set. For performance, it is advised to use the `organization_id` as a lookup if possible.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[str]:
        """
        The ID of the organization. If not provided, `name` must be set.
        """
        return pulumi.get(self, "organization_id")


class AwaitableGetOrganizationResult(GetOrganizationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOrganizationResult(
            brandings=self.brandings,
            connections=self.connections,
            display_name=self.display_name,
            id=self.id,
            members=self.members,
            metadata=self.metadata,
            name=self.name,
            organization_id=self.organization_id)


def get_organization(name: Optional[str] = None,
                     organization_id: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOrganizationResult:
    """
    Data source to retrieve a specific Auth0 organization by `organization_id` or `name`.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_auth0 as auth0

    # An Auth0 Organization loaded using its name.
    some_organization_by_name = auth0.get_organization(name="my-org")
    # An Auth0 Organization loaded using its ID.
    some_organization_by_id = auth0.get_organization(organization_id="org_abcdefghkijklmnopqrstuvwxyz0123456789")
    ```


    :param str name: The name of the organization. If not provided, `organization_id` must be set. For performance, it is advised to use the `organization_id` as a lookup if possible.
    :param str organization_id: The ID of the organization. If not provided, `name` must be set.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['organizationId'] = organization_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('auth0:index/getOrganization:getOrganization', __args__, opts=opts, typ=GetOrganizationResult).value

    return AwaitableGetOrganizationResult(
        brandings=pulumi.get(__ret__, 'brandings'),
        connections=pulumi.get(__ret__, 'connections'),
        display_name=pulumi.get(__ret__, 'display_name'),
        id=pulumi.get(__ret__, 'id'),
        members=pulumi.get(__ret__, 'members'),
        metadata=pulumi.get(__ret__, 'metadata'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'))


@_utilities.lift_output_func(get_organization)
def get_organization_output(name: Optional[pulumi.Input[Optional[str]]] = None,
                            organization_id: Optional[pulumi.Input[Optional[str]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetOrganizationResult]:
    """
    Data source to retrieve a specific Auth0 organization by `organization_id` or `name`.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_auth0 as auth0

    # An Auth0 Organization loaded using its name.
    some_organization_by_name = auth0.get_organization(name="my-org")
    # An Auth0 Organization loaded using its ID.
    some_organization_by_id = auth0.get_organization(organization_id="org_abcdefghkijklmnopqrstuvwxyz0123456789")
    ```


    :param str name: The name of the organization. If not provided, `organization_id` must be set. For performance, it is advised to use the `organization_id` as a lookup if possible.
    :param str organization_id: The ID of the organization. If not provided, `name` must be set.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ClientCredentialsArgs', 'ClientCredentials']

@pulumi.input_type
class ClientCredentialsArgs:
    def __init__(__self__, *,
                 authentication_method: pulumi.Input[str],
                 client_id: pulumi.Input[str],
                 client_secret: Optional[pulumi.Input[str]] = None,
                 private_key_jwt: Optional[pulumi.Input['ClientCredentialsPrivateKeyJwtArgs']] = None):
        """
        The set of arguments for constructing a ClientCredentials resource.
        :param pulumi.Input[str] authentication_method: Configure the method to use when making requests to any endpoint that requires this client to authenticate. Options include `none` (public client without a client secret), `client_secret_post` (confidential client using HTTP POST parameters), `client_secret_basic` (confidential client using HTTP Basic), `private_key_jwt` (confidential client using a Private Key JWT).
        :param pulumi.Input[str] client_id: The ID of the client for which to configure the authentication method.
        :param pulumi.Input['ClientCredentialsPrivateKeyJwtArgs'] private_key_jwt: Defines `private_key_jwt` client authentication method.
        """
        pulumi.set(__self__, "authentication_method", authentication_method)
        pulumi.set(__self__, "client_id", client_id)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if private_key_jwt is not None:
            pulumi.set(__self__, "private_key_jwt", private_key_jwt)

    @property
    @pulumi.getter(name="authenticationMethod")
    def authentication_method(self) -> pulumi.Input[str]:
        """
        Configure the method to use when making requests to any endpoint that requires this client to authenticate. Options include `none` (public client without a client secret), `client_secret_post` (confidential client using HTTP POST parameters), `client_secret_basic` (confidential client using HTTP Basic), `private_key_jwt` (confidential client using a Private Key JWT).
        """
        return pulumi.get(self, "authentication_method")

    @authentication_method.setter
    def authentication_method(self, value: pulumi.Input[str]):
        pulumi.set(self, "authentication_method", value)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Input[str]:
        """
        The ID of the client for which to configure the authentication method.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "client_id", value)

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_secret", value)

    @property
    @pulumi.getter(name="privateKeyJwt")
    def private_key_jwt(self) -> Optional[pulumi.Input['ClientCredentialsPrivateKeyJwtArgs']]:
        """
        Defines `private_key_jwt` client authentication method.
        """
        return pulumi.get(self, "private_key_jwt")

    @private_key_jwt.setter
    def private_key_jwt(self, value: Optional[pulumi.Input['ClientCredentialsPrivateKeyJwtArgs']]):
        pulumi.set(self, "private_key_jwt", value)


@pulumi.input_type
class _ClientCredentialsState:
    def __init__(__self__, *,
                 authentication_method: Optional[pulumi.Input[str]] = None,
                 client_id: Optional[pulumi.Input[str]] = None,
                 client_secret: Optional[pulumi.Input[str]] = None,
                 private_key_jwt: Optional[pulumi.Input['ClientCredentialsPrivateKeyJwtArgs']] = None):
        """
        Input properties used for looking up and filtering ClientCredentials resources.
        :param pulumi.Input[str] authentication_method: Configure the method to use when making requests to any endpoint that requires this client to authenticate. Options include `none` (public client without a client secret), `client_secret_post` (confidential client using HTTP POST parameters), `client_secret_basic` (confidential client using HTTP Basic), `private_key_jwt` (confidential client using a Private Key JWT).
        :param pulumi.Input[str] client_id: The ID of the client for which to configure the authentication method.
        :param pulumi.Input['ClientCredentialsPrivateKeyJwtArgs'] private_key_jwt: Defines `private_key_jwt` client authentication method.
        """
        if authentication_method is not None:
            pulumi.set(__self__, "authentication_method", authentication_method)
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if private_key_jwt is not None:
            pulumi.set(__self__, "private_key_jwt", private_key_jwt)

    @property
    @pulumi.getter(name="authenticationMethod")
    def authentication_method(self) -> Optional[pulumi.Input[str]]:
        """
        Configure the method to use when making requests to any endpoint that requires this client to authenticate. Options include `none` (public client without a client secret), `client_secret_post` (confidential client using HTTP POST parameters), `client_secret_basic` (confidential client using HTTP Basic), `private_key_jwt` (confidential client using a Private Key JWT).
        """
        return pulumi.get(self, "authentication_method")

    @authentication_method.setter
    def authentication_method(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "authentication_method", value)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the client for which to configure the authentication method.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_id", value)

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_secret", value)

    @property
    @pulumi.getter(name="privateKeyJwt")
    def private_key_jwt(self) -> Optional[pulumi.Input['ClientCredentialsPrivateKeyJwtArgs']]:
        """
        Defines `private_key_jwt` client authentication method.
        """
        return pulumi.get(self, "private_key_jwt")

    @private_key_jwt.setter
    def private_key_jwt(self, value: Optional[pulumi.Input['ClientCredentialsPrivateKeyJwtArgs']]):
        pulumi.set(self, "private_key_jwt", value)


class ClientCredentials(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_method: Optional[pulumi.Input[str]] = None,
                 client_id: Optional[pulumi.Input[str]] = None,
                 client_secret: Optional[pulumi.Input[str]] = None,
                 private_key_jwt: Optional[pulumi.Input[pulumi.InputType['ClientCredentialsPrivateKeyJwtArgs']]] = None,
                 __props__=None):
        """
        With this resource, you can configure the method to use when making requests to any endpoint that requires this client to authenticate.

        > Refer to the client secret rotation guide
        for instructions on how to rotate client secrets with zero downtime.

        ## Import

        This resource can be imported by specifying the client ID.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/clientCredentials:ClientCredentials my_creds "AaiyAPdpYdesoKnqjj8HJqRn4T5titww"
        ```

        ~> Importing this resource when the `authentication_method` is set to `private_key_jwt` will force the resource to be recreated.

        This is to be expected, because the pem file can't be checked for differences.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] authentication_method: Configure the method to use when making requests to any endpoint that requires this client to authenticate. Options include `none` (public client without a client secret), `client_secret_post` (confidential client using HTTP POST parameters), `client_secret_basic` (confidential client using HTTP Basic), `private_key_jwt` (confidential client using a Private Key JWT).
        :param pulumi.Input[str] client_id: The ID of the client for which to configure the authentication method.
        :param pulumi.Input[pulumi.InputType['ClientCredentialsPrivateKeyJwtArgs']] private_key_jwt: Defines `private_key_jwt` client authentication method.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClientCredentialsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        With this resource, you can configure the method to use when making requests to any endpoint that requires this client to authenticate.

        > Refer to the client secret rotation guide
        for instructions on how to rotate client secrets with zero downtime.

        ## Import

        This resource can be imported by specifying the client ID.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/clientCredentials:ClientCredentials my_creds "AaiyAPdpYdesoKnqjj8HJqRn4T5titww"
        ```

        ~> Importing this resource when the `authentication_method` is set to `private_key_jwt` will force the resource to be recreated.

        This is to be expected, because the pem file can't be checked for differences.

        :param str resource_name: The name of the resource.
        :param ClientCredentialsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClientCredentialsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_method: Optional[pulumi.Input[str]] = None,
                 client_id: Optional[pulumi.Input[str]] = None,
                 client_secret: Optional[pulumi.Input[str]] = None,
                 private_key_jwt: Optional[pulumi.Input[pulumi.InputType['ClientCredentialsPrivateKeyJwtArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClientCredentialsArgs.__new__(ClientCredentialsArgs)

            if authentication_method is None and not opts.urn:
                raise TypeError("Missing required property 'authentication_method'")
            __props__.__dict__["authentication_method"] = authentication_method
            if client_id is None and not opts.urn:
                raise TypeError("Missing required property 'client_id'")
            __props__.__dict__["client_id"] = client_id
            __props__.__dict__["client_secret"] = None if client_secret is None else pulumi.Output.secret(client_secret)
            __props__.__dict__["private_key_jwt"] = private_key_jwt
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["clientSecret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ClientCredentials, __self__).__init__(
            'auth0:index/clientCredentials:ClientCredentials',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authentication_method: Optional[pulumi.Input[str]] = None,
            client_id: Optional[pulumi.Input[str]] = None,
            client_secret: Optional[pulumi.Input[str]] = None,
            private_key_jwt: Optional[pulumi.Input[pulumi.InputType['ClientCredentialsPrivateKeyJwtArgs']]] = None) -> 'ClientCredentials':
        """
        Get an existing ClientCredentials resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] authentication_method: Configure the method to use when making requests to any endpoint that requires this client to authenticate. Options include `none` (public client without a client secret), `client_secret_post` (confidential client using HTTP POST parameters), `client_secret_basic` (confidential client using HTTP Basic), `private_key_jwt` (confidential client using a Private Key JWT).
        :param pulumi.Input[str] client_id: The ID of the client for which to configure the authentication method.
        :param pulumi.Input[pulumi.InputType['ClientCredentialsPrivateKeyJwtArgs']] private_key_jwt: Defines `private_key_jwt` client authentication method.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClientCredentialsState.__new__(_ClientCredentialsState)

        __props__.__dict__["authentication_method"] = authentication_method
        __props__.__dict__["client_id"] = client_id
        __props__.__dict__["client_secret"] = client_secret
        __props__.__dict__["private_key_jwt"] = private_key_jwt
        return ClientCredentials(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authenticationMethod")
    def authentication_method(self) -> pulumi.Output[str]:
        """
        Configure the method to use when making requests to any endpoint that requires this client to authenticate. Options include `none` (public client without a client secret), `client_secret_post` (confidential client using HTTP POST parameters), `client_secret_basic` (confidential client using HTTP Basic), `private_key_jwt` (confidential client using a Private Key JWT).
        """
        return pulumi.get(self, "authentication_method")

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[str]:
        """
        The ID of the client for which to configure the authentication method.
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> pulumi.Output[str]:
        return pulumi.get(self, "client_secret")

    @property
    @pulumi.getter(name="privateKeyJwt")
    def private_key_jwt(self) -> pulumi.Output[Optional['outputs.ClientCredentialsPrivateKeyJwt']]:
        """
        Defines `private_key_jwt` client authentication method.
        """
        return pulumi.get(self, "private_key_jwt")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['OrganizationMemberArgs', 'OrganizationMember']

@pulumi.input_type
class OrganizationMemberArgs:
    def __init__(__self__, *,
                 organization_id: pulumi.Input[str],
                 user_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a OrganizationMember resource.
        :param pulumi.Input[str] organization_id: The ID of the organization to assign the member to.
        :param pulumi.Input[str] user_id: ID of the user to add as an organization member.
        """
        pulumi.set(__self__, "organization_id", organization_id)
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Input[str]:
        """
        The ID of the organization to assign the member to.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[str]:
        """
        ID of the user to add as an organization member.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _OrganizationMemberState:
    def __init__(__self__, *,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering OrganizationMember resources.
        :param pulumi.Input[str] organization_id: The ID of the organization to assign the member to.
        :param pulumi.Input[str] user_id: ID of the user to add as an organization member.
        """
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the organization to assign the member to.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the user to add as an organization member.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_id", value)


class OrganizationMember(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource is used to manage the assignment of members and their roles within an organization.

        !> This resource appends a member to an organization. In contrast, the `OrganizationMembers` resource manages
        all the members assigned to an organization. To avoid potential issues, it is recommended not to use this resource in
        conjunction with the `OrganizationMembers` resource when managing members for the same organization id.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        user = auth0.User("user",
            email="test-user@auth0.com",
            connection_name="Username-Password-Authentication",
            email_verified=True,
            password="MyPass123$")
        my_org = auth0.Organization("my_org",
            name="org-admin",
            display_name="Admin")
        my_org_member = auth0.OrganizationMember("my_org_member",
            organization_id=my_org.id,
            user_id=user.id)
        ```

        ## Import

        This resource can be imported by specifying the

        organization ID and user ID separated by "::" (note the double colon)

        <organizationID>::<userID>

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/organizationMember:OrganizationMember my_org_member "org_XXXXX::auth0|XXXXX"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] organization_id: The ID of the organization to assign the member to.
        :param pulumi.Input[str] user_id: ID of the user to add as an organization member.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OrganizationMemberArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource is used to manage the assignment of members and their roles within an organization.

        !> This resource appends a member to an organization. In contrast, the `OrganizationMembers` resource manages
        all the members assigned to an organization. To avoid potential issues, it is recommended not to use this resource in
        conjunction with the `OrganizationMembers` resource when managing members for the same organization id.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        user = auth0.User("user",
            email="test-user@auth0.com",
            connection_name="Username-Password-Authentication",
            email_verified=True,
            password="MyPass123$")
        my_org = auth0.Organization("my_org",
            name="org-admin",
            display_name="Admin")
        my_org_member = auth0.OrganizationMember("my_org_member",
            organization_id=my_org.id,
            user_id=user.id)
        ```

        ## Import

        This resource can be imported by specifying the

        organization ID and user ID separated by "::" (note the double colon)

        <organizationID>::<userID>

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/organizationMember:OrganizationMember my_org_member "org_XXXXX::auth0|XXXXX"
        ```

        :param str resource_name: The name of the resource.
        :param OrganizationMemberArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OrganizationMemberArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OrganizationMemberArgs.__new__(OrganizationMemberArgs)

            if organization_id is None and not opts.urn:
                raise TypeError("Missing required property 'organization_id'")
            __props__.__dict__["organization_id"] = organization_id
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
        super(OrganizationMember, __self__).__init__(
            'auth0:index/organizationMember:OrganizationMember',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            user_id: Optional[pulumi.Input[str]] = None) -> 'OrganizationMember':
        """
        Get an existing OrganizationMember resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] organization_id: The ID of the organization to assign the member to.
        :param pulumi.Input[str] user_id: ID of the user to add as an organization member.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OrganizationMemberState.__new__(_OrganizationMemberState)

        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["user_id"] = user_id
        return OrganizationMember(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        The ID of the organization to assign the member to.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[str]:
        """
        ID of the user to add as an organization member.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RolePermissionsArgs', 'RolePermissions']

@pulumi.input_type
class RolePermissionsArgs:
    def __init__(__self__, *,
                 permissions: pulumi.Input[Sequence[pulumi.Input['RolePermissionsPermissionArgs']]],
                 role_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a RolePermissions resource.
        :param pulumi.Input[Sequence[pulumi.Input['RolePermissionsPermissionArgs']]] permissions: List of API permissions granted to the role.
        :param pulumi.Input[str] role_id: ID of the role to associate the permission to.
        """
        pulumi.set(__self__, "permissions", permissions)
        pulumi.set(__self__, "role_id", role_id)

    @property
    @pulumi.getter
    def permissions(self) -> pulumi.Input[Sequence[pulumi.Input['RolePermissionsPermissionArgs']]]:
        """
        List of API permissions granted to the role.
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: pulumi.Input[Sequence[pulumi.Input['RolePermissionsPermissionArgs']]]):
        pulumi.set(self, "permissions", value)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Input[str]:
        """
        ID of the role to associate the permission to.
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_id", value)


@pulumi.input_type
class _RolePermissionsState:
    def __init__(__self__, *,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input['RolePermissionsPermissionArgs']]]] = None,
                 role_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering RolePermissions resources.
        :param pulumi.Input[Sequence[pulumi.Input['RolePermissionsPermissionArgs']]] permissions: List of API permissions granted to the role.
        :param pulumi.Input[str] role_id: ID of the role to associate the permission to.
        """
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if role_id is not None:
            pulumi.set(__self__, "role_id", role_id)

    @property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RolePermissionsPermissionArgs']]]]:
        """
        List of API permissions granted to the role.
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RolePermissionsPermissionArgs']]]]):
        pulumi.set(self, "permissions", value)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the role to associate the permission to.
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_id", value)


class RolePermissions(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RolePermissionsPermissionArgs']]]]] = None,
                 role_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        With this resource, you can manage role permissions (1-many).

        !> This resource manages all the permissions assigned to a role. In contrast, the `RolePermission` resource only
        appends a permission to a role. To avoid potential issues, it is recommended not to use this resource in conjunction
        with the `RolePermission` resource when managing permissions for the same role id.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # Example:
        resource_server = auth0.ResourceServer("resource_server",
            name="test",
            identifier="test.example.com")
        resource_server_scopes = auth0.ResourceServerScopes("resource_server_scopes",
            resource_server_identifier=resource_server.identifier,
            scopes=[
                auth0.ResourceServerScopesScopeArgs(
                    name="store:create",
                ),
                auth0.ResourceServerScopesScopeArgs(
                    name="store:read",
                ),
                auth0.ResourceServerScopesScopeArgs(
                    name="store:update",
                ),
                auth0.ResourceServerScopesScopeArgs(
                    name="store:delete",
                ),
            ])
        my_role = auth0.Role("my_role", name="My Role")
        my_role_perms = auth0.RolePermissions("my_role_perms",
            permissions=resource_server.identifier.apply(lambda identifier: [{
                "name": entry["value"],
                "resourceServerIdentifier": identifier,
            } for entry in resource_server_scopes.scopes.apply(lambda scopes: [{"key": k, "value": v} for k, v in scopes])]),
            role_id=my_role.id)
        ```

        ## Import

        This resource can be imported by specifying the role ID

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/rolePermissions:RolePermissions all_role_permissions "rol_XXXXXXXXXXXX"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RolePermissionsPermissionArgs']]]] permissions: List of API permissions granted to the role.
        :param pulumi.Input[str] role_id: ID of the role to associate the permission to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RolePermissionsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        With this resource, you can manage role permissions (1-many).

        !> This resource manages all the permissions assigned to a role. In contrast, the `RolePermission` resource only
        appends a permission to a role. To avoid potential issues, it is recommended not to use this resource in conjunction
        with the `RolePermission` resource when managing permissions for the same role id.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # Example:
        resource_server = auth0.ResourceServer("resource_server",
            name="test",
            identifier="test.example.com")
        resource_server_scopes = auth0.ResourceServerScopes("resource_server_scopes",
            resource_server_identifier=resource_server.identifier,
            scopes=[
                auth0.ResourceServerScopesScopeArgs(
                    name="store:create",
                ),
                auth0.ResourceServerScopesScopeArgs(
                    name="store:read",
                ),
                auth0.ResourceServerScopesScopeArgs(
                    name="store:update",
                ),
                auth0.ResourceServerScopesScopeArgs(
                    name="store:delete",
                ),
            ])
        my_role = auth0.Role("my_role", name="My Role")
        my_role_perms = auth0.RolePermissions("my_role_perms",
            permissions=resource_server.identifier.apply(lambda identifier: [{
                "name": entry["value"],
                "resourceServerIdentifier": identifier,
            } for entry in resource_server_scopes.scopes.apply(lambda scopes: [{"key": k, "value": v} for k, v in scopes])]),
            role_id=my_role.id)
        ```

        ## Import

        This resource can be imported by specifying the role ID

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/rolePermissions:RolePermissions all_role_permissions "rol_XXXXXXXXXXXX"
        ```

        :param str resource_name: The name of the resource.
        :param RolePermissionsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RolePermissionsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RolePermissionsPermissionArgs']]]]] = None,
                 role_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RolePermissionsArgs.__new__(RolePermissionsArgs)

            if permissions is None and not opts.urn:
                raise TypeError("Missing required property 'permissions'")
            __props__.__dict__["permissions"] = permissions
            if role_id is None and not opts.urn:
                raise TypeError("Missing required property 'role_id'")
            __props__.__dict__["role_id"] = role_id
        super(RolePermissions, __self__).__init__(
            'auth0:index/rolePermissions:RolePermissions',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            permissions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RolePermissionsPermissionArgs']]]]] = None,
            role_id: Optional[pulumi.Input[str]] = None) -> 'RolePermissions':
        """
        Get an existing RolePermissions resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RolePermissionsPermissionArgs']]]] permissions: List of API permissions granted to the role.
        :param pulumi.Input[str] role_id: ID of the role to associate the permission to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RolePermissionsState.__new__(_RolePermissionsState)

        __props__.__dict__["permissions"] = permissions
        __props__.__dict__["role_id"] = role_id
        return RolePermissions(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def permissions(self) -> pulumi.Output[Sequence['outputs.RolePermissionsPermission']]:
        """
        List of API permissions granted to the role.
        """
        return pulumi.get(self, "permissions")

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Output[str]:
        """
        ID of the role to associate the permission to.
        """
        return pulumi.get(self, "role_id")

